@@ -1,5 +1,6 @@
-"""Graph analysis module."""
+"""# Graph analysis"""
 
 from logging import getLogger
 
 logger = getLogger("ragraph.analysis")
+"""Logger for the graph analysis module."""
