@@ -98,9 +98,7 @@ class LeafsCast(Cast):
         if value is None:
             root = cast(self.root)
             leafs = (
-                self.graph.leafs
-                if root is None
-                else [n for n in root.descendant_gen if n.is_leaf]
+                self.graph.leafs if root is None else [n for n in root.descendant_gen if n.is_leaf]
             )
         else:
             leafs = [n for n in (cast(leaf) for leaf in value) if n is not None]
@@ -196,9 +194,7 @@ class Parameter:
                     f"'{self.cast}' into a '{self.type}'."
                 )
         if self.enum is not None and value not in self.enum:
-            raise ValueError(
-                f"Value '{value}' is not allowed, try one of '{self.enum}'."
-            )
+            raise ValueError(f"Value '{value}' is not allowed, try one of '{self.enum}'.")
         if self.lower is not None:
             assert value > self.lower
         if self.upper is not None:
@@ -360,9 +356,7 @@ class Analysis:
             try:
                 f_param = sig.parameters[pname]
             except KeyError:
-                raise ValueError(
-                    f"Parameter {pname} is missing in the signature of '{func}'."
-                )
+                raise ValueError(f"Parameter {pname} is missing in the signature of '{func}'.")
 
             # Inherit default kwarg values.
             func.__annotations__[pname] = param.type
@@ -411,8 +405,7 @@ class Analysis:
 
 class BusAnalysis(Analysis):
     _default_parameters = {
-        p.name: p
-        for p in [graph, root, leafs, inherit, loops, edge_weights, names, safe]
+        p.name: p for p in [graph, root, leafs, inherit, loops, edge_weights, names, safe]
     }
     _returns = [
         "Detected bus nodes (or names thereof).",
@@ -444,8 +437,7 @@ class BusAnalysis(Analysis):
             # Nontrivial case, need to execute:
             else:
                 self.log(
-                    "Applying bus analysis to leafs "
-                    + f"'{[n.name for n in kw['leafs']]}'..."
+                    "Applying bus analysis to leafs " + f"'{[n.name for n in kw['leafs']]}'..."
                 )
                 bus_leafs, nonbus_leafs = func(**kw)
 
@@ -490,9 +482,7 @@ class ClusterAnalysis(Analysis):
             if not kw["inplace"]:
                 kw["graph"] = deepcopy(kw["graph"])
                 kw["leafs"] = [kw["graph"].node_dict[n.name] for n in kw["leafs"]]
-                kw["root"] = (
-                    kw["graph"].node_dict[kw["root"].name] if kw.get("root") else None
-                )
+                kw["root"] = kw["graph"].node_dict[kw["root"].name] if kw.get("root") else None
 
             # Trivial cases where there is nothing to cluster.
             if len(kw["leafs"]) < 2:
@@ -512,9 +502,7 @@ class ClusterAnalysis(Analysis):
                 # Execution
                 self.log("Applying cluster algorithm...")
                 graph, clusters = func(**kw)
-                self.log(
-                    f"Found {len(clusters)} clusters for {len(kw['leafs'])} leafs."
-                )
+                self.log(f"Found {len(clusters)} clusters for {len(kw['leafs'])} leafs.")
 
             # Postprocess results.
             if kw.get("root"):
