@@ -8,7 +8,7 @@ sort_by_name_analysis = SequenceAnalysis("Sort by name")
 
 
 @sort_by_name_analysis
-def sort_by_name(
+def name(
     graph: Graph,
     root: Optional[Union[str, Node]] = None,
     nodes: Optional[Union[List[str], List[Node]]] = None,
