@@ -1,4 +1,4 @@
-"""Color utility methods."""
+"""# Color utilities"""
 from typing import Tuple
 
 
