@@ -1,4 +1,4 @@
-"""Kodak Single-Use Camera product commonality dataset.
+"""# Kodak Single-Use Camera product commonality
 
 This DSM dataset was actually proposed as a "3D DSM" as it was featured in the reference
 papers in a 3D layered fashion. Relationships between components in a product family for
@@ -16,17 +16,19 @@ dependency occurs in the corresponding camera type.
 
 Available labels for nodes or edges:
 
-    - Fun Saver
-    - Outdoor
-    - Plus Digital
+- Fun Saver
+- Outdoor
+- Plus Digital
 
-References:
-Alizon, Fabrice. 2009, February. Module-Based Design Management-Synerg'. Symposium on
-Product Family & Product Platform Design, Helsinki University of Technology (TKK),
-Helsinki, Finland.
-Alizon, Fabrice, Seung K. Moon, Steven B. Shooter, and Timothy W. Simpson. 2007,
-September 4--7. Three Dimensional Design Structure Matrix-DSM3D. ASME Design Engineering
-Technical Conferences, DETCZ007-34510, Las Vegas, NV, pp. 941-948.
+Reference:
+    Alizon, Fabrice. 2009, February. Module-Based Design Management-Synerg'. Symposium on
+    Product Family & Product Platform Design, Helsinki University of Technology (TKK),
+    Helsinki, Finland.
+
+Reference:
+    Alizon, Fabrice, Seung K. Moon, Steven B. Shooter, and Timothy W. Simpson. 2007,
+    September 4--7. Three Dimensional Design Structure Matrix-DSM3D. ASME Design Engineering
+    Technical Conferences, DETCZ007-34510, Las Vegas, NV, pp. 941-948.
 """
 
 
