@@ -1,4 +1,4 @@
-"""UCAV (unmanned combat aerial vehicle) preliminary design process graph.
+"""# UCAV (unmanned combat aerial vehicle) preliminary design process.
 
 The graph contains 14 preliminary design activities. Each phase consists of an initial
 activity to define design several disciplines-such as aerodynamics, propulsion,
@@ -17,8 +17,8 @@ succesfully executed, there is a rework probability that the activity needs to b
 redone, the impact then indicates the percentage that needs to be redone and the
 improvement curve decreases this in successive iterations.
 
-Reference: Eppinger, S. D., & Browning, T. R. (2012). Design Structure Matrix - Methods
-and Applications.
+Reference:
+    Eppinger, S. D., & Browning, T. R. (2012). Design Structure Matrix - Methods and Applications.
 """
 
 node_weights = [
