@@ -15,24 +15,25 @@ class MappingValidationError(Exception):
 
 
 def field(fget: Callable):
-    """A :obj:`Mapping` field is a property that utilizes the :obj:`Mapping`'s data.
+    """A [`Mapping`][ragraph.generic.Mapping] `field` is a property that utilizes the
+    [`Mapping`][ragraph.generic.Mapping]'s data.
 
     Use it like the ``@property`` decorator and leave the function body blank (or pass):
 
     By inspecting the wrapped method's name we derive the property's key.
 
-    Getting data from the mapping is done by retrieving the key from the set values.
-    If that key is not found, an attempt is made on the defaults.
-    An error is thrown when the key is neither to be found in the data or defaults.
+    Getting data from the mapping is done by retrieving the key from the set values. If that key is
+    not found, an attempt is made on the defaults. An error is thrown when the key is neither to be
+    found in the data or defaults.
 
-    Setting data checks for nested :obj:`Mapping` keys to update those and otherwise
-    defaults to simply storing the value. Updating a nested :obj:`Mapping` field only
-    updates the keys that are provided.
+    Setting data checks for nested [`Mapping`][ragraph.generic.Mapping] keys to update those and
+    otherwise defaults to simply storing the value. Updating a nested
+    [`Mapping`][ragraph.generic.Mapping] field only updates the keys that are provided.
 
     Deleting data pops the key from the set values, but does not remove any defaults.
 
     Note:
-        The method contents of a :obj:`Mapping` :obj:`field` are ignored.
+        The method contents of a [`Mapping`][ragraph.generic.Mapping] `field` are ignored.
     """
     key = fget.__name__
 
@@ -44,9 +45,7 @@ def field(fget: Callable):
         if key in self._defaults:
             return self._defaults[key]
 
-        raise AttributeError(
-            f"Mapping does not contain a (default) value for key '{key}'."
-        )
+        raise AttributeError(f"Mapping does not contain a (default) value for key '{key}'.")
 
     def setter(self, value: Any):
         """Set a mapping value."""
@@ -83,29 +82,31 @@ class Mapping:
     It's possible to include allowed keys, default values, and optional validators for
     certain keys/properties of a derived class.
 
-    .. doctest::
+    ```py
+    from ragraph.generic import Mapping, field
+    def check_int(value):
+        assert value == 1
 
-        >>> from ragraph.generic import Mapping, field
-        >>> def check_int(value):
-        ...     assert value == 1
-        ...
-        >>> class MyMap(Mapping):
-        ...     _protected = True
-        ...     _defaults = dict(myfield=1)
-        ...     _validators = dict(myfield=check_int)
-        ...     @field
-        ...     def myfield(self) -> int:
-        ...         '''My field's docstring'''
-        ...
-        >>> m = MyMap(myfield=3)
-        >>> assert m.myfield == 3,            "This should return our set value."
-        >>> assert m.myfield == m['myfield'], "A mapping works like a dictionary."
-        >>> del(m.myfield)                   # This deletes our override.
-        >>> m.validate()                     # Checks whether myfield == 1.
+    class MyMap(Mapping):
+        _protected = True
+        _defaults = dict(myfield=1)
+        _validators = dict(myfield=check_int)
+        @field
+        def myfield(self) -> int:
+            '''My field's docstring'''
+
+    m = MyMap(myfield=3)
+    assert m.myfield == 3,            "This should return our set value."
+    assert m.myfield == m['myfield'], "A mapping works like a dictionary."
+    del(m.myfield)                    # This deletes our override.
+    m.validate()                      # Checks whether myfield == 1.
+    ```
     """
 
     _protected = False
-    """Setting public properties is restricted to those in :obj:`self.keys`."""
+    """Setting public properties is restricted to those in
+    [`self.keys`][ragraph.generic.Mapping.keys].
+    """
 
     _defaults: Dict[str, Any] = dict()
     """Default values for included keys."""
@@ -114,8 +115,9 @@ class Mapping:
     """Set of always allowed keys to set."""
 
     _validators: Dict[str, Callable] = dict()
-    """Validators for included keys. Used when calling :obj:`self.validate`.
-    Also see :obj:`self._post_validation`."""
+    """Validators for included keys. Used when calling
+    [`self.validate`][ragraph.generic.Mapping.validate].
+    Also see [`self._post_validation`][ragraph.generic.Mapping._post_validation]."""
 
     def __init__(self, *args, **kwargs):
         # The internal storage dictionary.
@@ -151,16 +153,13 @@ class Mapping:
         """Set an attribute : `self.key = value`.
 
         Private properties are left untouched, public properties need permission.
-        See :obj:`self._check_allowed`.
         """
         if not key.startswith("_"):
             keys = set() if self._keys is None else self._keys
             keys = keys.union(self.keys())
             if key not in keys:
                 if self._protected:
-                    raise KeyError(
-                        f"Key or property '{key}' is not allowed. Only '{keys}'."
-                    )
+                    raise KeyError(f"Key or property '{key}' is not allowed. Only '{keys}'.")
                 else:
                     # Dynamically create a new field.
                     def stub(self):
@@ -176,11 +175,10 @@ class Mapping:
         """Set an attribute via a dictionary accessor: `self['key'] = value`.
 
         Private properties are left untouched, public properties need permission.
-        See :obj:`self._check_allowed`.
         """
         setattr(self, key, value)
 
-    def update(self, *args, **kwargs) -> None:
+    def update(self, *args: Dict[str, Any], **kwargs: Any) -> None:
         """Update multiple keys at once.
 
         Arguments:
@@ -192,9 +190,7 @@ class Mapping:
                 for key, value in arg.items():
                     setattr(self, key, value)
             except AttributeError:
-                raise TypeError(
-                    f"Expected a dictionary or a Mapping. Found a {type(arg)}."
-                )
+                raise TypeError(f"Expected a dictionary or a Mapping. Found a {type(arg)}.")
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -253,7 +249,7 @@ class Mapping:
         pass
 
     def as_dict(self) -> Dict[str, Any]:
-        """Return a copy as a dictionary with all submappings as dictionaries, too."""
+        """Return a copy as a dictionary with all sub-mappings as dictionaries, too."""
         m = self._defaults.copy()
         m.update(self._data)
         for key, value in m.items():
@@ -274,7 +270,7 @@ class Bound:
     Arguments:
         value: Numerical bound value.
         inclusive: Whether the bound is inclusive.
-        report: Whether to report an "error", "warn" or nothing (``None``) on
+        report: Whether to report an "error", "warn" or nothing (`None`) on
             bound violations.
     """
 
@@ -375,12 +371,12 @@ class Metadata:
     """Metadata for graph elements.
 
     Arguments:
-        name: Instance name. Set to a copy of the UUID if :obj:`None` provided.
+        name: Instance name. Set to a copy of the UUID if `None` provided.
         kind: Kind or main category of this instance.
         labels: Labels categorizing this instance.
         weights: Dictionary of weights attached to this instance.
         annotations: Miscellaneous properties of this instance.
-        uuid: UUID of this instance, generated when :obj:`None` provided.
+        uuid: UUID of this instance, generated when `None` provided.
     """
 
     def __init__(
@@ -488,7 +484,7 @@ class Metadata:
     def weight(self) -> Union[int, float]:
         """Cumulative weight of this instance (read-only).
 
-        Returns the sum of :obj:`self.weights`.
+        Returns the sum of [`self.weights`][ragraph.generic.Metadata.weights].
         """
         return sum(self._weights.values())
 
@@ -496,7 +492,7 @@ class Metadata:
     def annotations(self) -> Annotations:
         """Annotations of this instance.
 
-        Defaults to an empty :obj:`Annotations` instance.
+        Defaults to an empty [`Annotations`][ragraph.generic.Annotations] instance.
         """
         return self._annotations
 
@@ -671,7 +667,7 @@ class MetadataOptions:
 
     def as_dict(self) -> Dict[str, Any]:
         """Serializable dictionary representation."""
-        result = dict(
+        result: Dict[str, Any] = dict(
             kinds=sorted(self.kinds),
             labels=sorted(self.labels),
             weights=sorted(self.weights),
