@@ -1,23 +1,12 @@
-"""Graph module. Contains Graph class definitions.
+"""# Graph class module
 
-The :obj:`Graph` class is the core of this package. It is the internal storage
+The [`Graph`][ragraph.graph.Graph] class is the core of this package. It is the internal storage
 format that facilitates all conversions. These class definitions are designed to
 accommodate a wide range of graph formats.
 """
 from collections import OrderedDict, defaultdict
 from copy import deepcopy
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Generator,
-    Iterable,
-    List,
-    Optional,
-    Set,
-    Tuple,
-    Union,
-)
+from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Set, Tuple, Union
 from uuid import UUID
 
 from ragraph import utils
@@ -37,7 +26,8 @@ class ConsistencyError(Exception):
 
 
 class Graph(Metadata):
-    """Graph of :obj:`Node` objects and :obj:`Edge` objects between them.
+    """Graph of [`Node`][ragraph.node.Node] objects and [`Edge`][ragraph.edge.Edge] objects between
+    them.
 
     Arguments:
         nodes: Iterable of graph nodes.
@@ -260,23 +250,17 @@ class Graph(Metadata):
             node: Node to add.
         """
         if not isinstance(node, Node):
-            raise TypeError(
-                "%r is not an instance of Node but of %r." % (node, type(node))
-            )
+            raise TypeError("%r is not an instance of Node but of %r." % (node, type(node)))
 
         # Append own node if not exists.
         if node.name in self._nodes:
             if node == self._nodes[node.name]:
                 return
-            raise ValueError(
-                f"Another Node named '{node.name}' already exists in this Graph."
-            )
+            raise ValueError(f"Another Node named '{node.name}' already exists in this Graph.")
         if node.uuid in self.node_uuid_dict:
             if node == self.node_uuid_dict[node.uuid]:
                 return
-            raise ValueError(
-                f"Another Node with UUID '{node.uuid}' already exists in this Graph."
-            )
+            raise ValueError(f"Another Node with UUID '{node.uuid}' already exists in this Graph.")
         self._nodes[node.name] = node
         self.node_uuid_dict[node.uuid] = node
 
@@ -321,8 +305,7 @@ class Graph(Metadata):
             edge: Edge to add.
 
         Raises:
-            A ValueError if the source or target doesn't exist or the edge instance
-            already does.
+            ValueError: if the source or target doesn't exist or the edge instance already does.
         """
         source = edge.source.name
         target = edge.target.name
@@ -396,9 +379,7 @@ class Graph(Metadata):
         """List of unique edge weight labels in the graph."""
         return self.get_weight_labels(self.edge_gen)
 
-    def get_weight_labels(
-        self, elements: Union[Iterable[Node], Iterable[Edge]]
-    ) -> List[str]:
+    def get_weight_labels(self, elements: Union[Iterable[Node], Iterable[Edge]]) -> List[str]:
         """Get an alphabetically sorted list of unique labels of node/edge weights."""
         labels: Set[str] = set()
         for elem in elements:
@@ -476,8 +457,8 @@ class Graph(Metadata):
         """Yield edges between source and target node.
 
         Arguments:
-            sources: Source nodes.
-            targets: Target nodes.
+            source: Source node.
+            target: Target node.
             inherit: Whether to include edges between descendants of given nodes.
             loops: Whether to include self-loop edges.
         """
@@ -513,9 +494,7 @@ class Graph(Metadata):
         """
         for source in sources:
             for target in targets:
-                yield from self.edges_between(
-                    source, target, inherit=inherit, loops=loops
-                )
+                yield from self.edges_between(source, target, inherit=inherit, loops=loops)
 
     def get_graph_slice(
         self,
@@ -538,11 +517,7 @@ class Graph(Metadata):
             changes! All parent and child nodes not in the list are excluded.
         """
         nodes = self.nodes if nodes is None else list(nodes)
-        edges = (
-            self.edges_between_all(nodes, nodes, inherit)
-            if edges is None
-            else list(edges)
-        )
+        edges = self.edges_between_all(nodes, nodes, inherit) if edges is None else list(edges)
 
         # Get a deepcopy to prevent changing nodes in the current graph instance.
         graph = deepcopy(Graph(nodes=nodes, edges=edges, add_children=inherit))
@@ -551,9 +526,7 @@ class Graph(Metadata):
         graph_nodes = graph.nodes
         for node in graph_nodes:
             if node.parent:
-                node.parent = (
-                    graph[node.parent.name] if node.parent in graph.nodes else None
-                )
+                node.parent = graph[node.parent.name] if node.parent in graph.nodes else None
             node.children = [c for c in node.children if c in graph.nodes]
             if node.is_bus and not node.parent:
                 node.is_bus = False
@@ -578,7 +551,7 @@ class Graph(Metadata):
         Note:
             The selection mode argument determines how nodes of different kinds are
             selected. If the selection mode is set to 'dependent', the first node kind
-            in the :obj:`node_kinds` list is considered to be the 'lead node kind'.
+            in the `node_kinds` list is considered to be the 'lead node kind'.
             Nodes of different kind than the lead node kind, are only selected if they
             have a dependency with at least one of the selected nodes of the lead node
             kind. If the selection mode is set to 'independent' this dependency
@@ -605,11 +578,7 @@ class Graph(Metadata):
         ekinds = edge_kinds or self.edge_kinds
         ekinds = sorted(set(ekinds))
 
-        return [
-            e
-            for e in self.edges_between_all(sources=nlist, targets=nlist)
-            if e.kind in ekinds
-        ]
+        return [e for e in self.edges_between_all(sources=nlist, targets=nlist) if e.kind in ekinds]
 
     def get_node_and_edge_selection(
         self,
@@ -629,7 +598,7 @@ class Graph(Metadata):
         Note:
             The selection mode argument determines how nodes of different kinds are
             selected. If the selection mode is set to 'dependent', the first node kind
-            in the :obj:`node_kinds` list is considered to be the 'lead node kind'.
+            in the `node_kinds` list is considered to be the 'lead node kind'.
             Nodes of different kind than the lead node kind, are only selected if they
             have a dependency with at least one of the selected nodes of the lead node
             kind. If the selection mode is set to 'independent' this dependency
@@ -647,9 +616,7 @@ class Graph(Metadata):
 
         return nodes, edges
 
-    def get_hierarchy_dict(
-        self, roots: Optional[List[Node]] = None, levels: Optional[int] = None
-    ):
+    def get_hierarchy_dict(self, roots: Optional[List[Node]] = None, levels: Optional[int] = None):
         """Return a dictionary of the (partial) hierarchical node structure.
 
         Arguments:
@@ -682,7 +649,7 @@ class Graph(Metadata):
             nodes: Optional list of nodes for which to get the adjacency matrix.
             inherit: Whether to count weights between children of the given nodes.
             loops: Whether to calculate self-loops from a node to itself.
-            only: Optional subset of edge weights to consider. See :obj:`Edge` for
+            only: Optional subset of edge weights to consider. See [`Edge`][ragraph.edge.Edge] for
                 default edge weight implementation.
 
         Returns:
@@ -691,9 +658,7 @@ class Graph(Metadata):
         """
         from ragraph.io.matrix import to_matrix
 
-        return to_matrix(
-            self, rows=nodes, cols=nodes, inherit=inherit, loops=loops, only=only
-        )
+        return to_matrix(self, rows=nodes, cols=nodes, inherit=inherit, loops=loops, only=only)
 
     def get_mapping_matrix(
         self,
@@ -706,12 +671,11 @@ class Graph(Metadata):
         """Convert graph data into a numerical mapping matrix.
 
         Arguments:
-            graph: Graph to fetch data from.
             rows: Nodes representing the matrix rows.
             cols: Nodes representing the matrix columns if different from the rows.
             inherit: Whether to count weights between children of the given nodes.
             loops: Whether to calculate self-loops from a node to itself.
-            only: Optional subset of edge weights to consider. See :obj:`Edge` for
+            only: Optional subset of edge weights to consider. See [`Edge`][ragraph.edge.Edge] for
                 default edge weight implementation.
 
         Returns:
@@ -720,16 +684,14 @@ class Graph(Metadata):
         """
         from ragraph.io.matrix import to_matrix
 
-        return to_matrix(
-            self, rows=rows, cols=cols, inherit=inherit, loops=loops, only=only
-        )
+        return to_matrix(self, rows=rows, cols=cols, inherit=inherit, loops=loops, only=only)
 
     def get_ascii_art(
         self,
         nodes: Optional[List[Node]] = None,
         edge: str = "X",
         diag: str = "\u25A0",
-        show: bool = True,
+        show: bool = False,
     ) -> Optional[str]:
         """Get a unicode ASCII art representation of a binary adjacency matrix for a
         given set of nodes.
@@ -749,7 +711,7 @@ class Graph(Metadata):
             raise ValueError("Empty graph, cannot create ASCII art.")
 
         namelens = [len(n.name) for n in nodes]
-        maxlen = max(namelens)
+        maxlen = max(namelens, default=0)
         dim = len(nodes)
 
         ddd = "\u2500\u2500\u2500"  # ---
@@ -763,7 +725,6 @@ class Graph(Metadata):
         lines = [topline]
 
         for i, tgt in enumerate(nodes):
-
             line = (maxlen - namelens[i]) * " " + tgt.name + "\u2525"
             for j, src in enumerate(nodes):
                 if i == j:
@@ -835,7 +796,7 @@ class Graph(Metadata):
         Returns:
             Whether nodes aren't their own ancestor/descendant and if all their children
             and parents exist in the graph. Raises an error for inconsistencies if
-            :obj:`raise_error` is set to `True`.
+            `raise_error` is set to `True`.
         """
         consistent = True
 
@@ -844,22 +805,16 @@ class Graph(Metadata):
                 a = node
                 while a.parent:
                     if a.parent == node:
-                        raise ConsistencyError(
-                            "Node {} is in its own ancestors.".format(node)
-                        )
+                        raise ConsistencyError("Node {} is in its own ancestors.".format(node))
                     a = a.parent
                 ds = node.children
                 while ds:
                     if node in ds:
-                        raise ConsistencyError(
-                            "Node {} is in its own descendants.".format(node)
-                        )
+                        raise ConsistencyError("Node {} is in its own descendants.".format(node))
                     ds = [c for d in ds for c in d.children]
                 if node.parent and node.parent not in self.node_list:
                     raise ConsistencyError(
-                        "Node {}'s parent {} is missing in the graph.".format(
-                            node, node.parent
-                        )
+                        "Node {}'s parent {} is missing in the graph.".format(node, node.parent)
                     )
                 if node.parent and node not in node.parent.children:
                     raise ConsistencyError(
@@ -870,32 +825,22 @@ class Graph(Metadata):
                 for child in node.children:
                     if child not in self.node_list:
                         raise ConsistencyError(
-                            "Node {}'s child {} is missing in the graph.".format(
-                                node, child
-                            )
+                            "Node {}'s child {} is missing in the graph.".format(node, child)
                         )
                     if child.parent != node:
                         raise ConsistencyError(
-                            "Node {}'s child has a different parent {}.".format(
-                                node, child.parent
-                            )
+                            "Node {}'s child has a different parent {}.".format(node, child.parent)
                         )
                 if node.is_bus and not node.parent:
                     raise ConsistencyError(
-                        "Node {} is a bus node, but has no parent to be it for.".format(
-                            node
-                        )
+                        "Node {} is a bus node, but has no parent to be it for.".format(node)
                     )
 
             for edge in self.edge_list:
                 if edge.source.name not in self.node_dict:
-                    raise ConsistencyError(
-                        f"Edge source not in Graph: {repr(edge.source)}"
-                    )
+                    raise ConsistencyError(f"Edge source not in Graph: {repr(edge.source)}")
                 if edge.target.name not in self.node_dict:
-                    raise ConsistencyError(
-                        f"Edge target not in Graph: {repr(edge.source)}"
-                    )
+                    raise ConsistencyError(f"Edge target not in Graph: {repr(edge.source)}")
 
         except ConsistencyError as e:
             consistent = False
@@ -906,12 +851,13 @@ class Graph(Metadata):
 
 
 class GraphView(Graph):
-    """A view on a :obj:`Graph` object. It works exactly like the :obj:`Graph` object,
-    except for that the nodes and edges are filtered according to the view function.
+    """A view on a [`Graph`][ragraph.graph.Graph] object. It works exactly like the
+    [`Graph`][ragraph.graph.Graph] object, except for that the nodes and edges are filtered
+    according to the view function.
 
     Arguments:
         graph: Graph to provide a view on.
-        view_func: View function that filters the :obj:`Graph`'s nodes and edges.
+        view_func: View function that filters the [`Graph`][ragraph.graph.Graph]'s nodes and edges.
         view_kwargs: Optional arguments to pass to the view function.
     """
 
@@ -971,7 +917,7 @@ class GraphView(Graph):
             ],
         ]
     ]:
-        """View function that filters the :obj:`Graph`'s nodes and edges."""
+        """View function that filters the [`Graph`][ragraph.graph.Graph]'s nodes and edges."""
         return self._view_func
 
     @view_func.setter
