@@ -1,4 +1,4 @@
-"""YAML dump/load module."""
+"""# YAML format support"""
 from pathlib import Path
 from typing import Optional, Union
 
@@ -13,9 +13,7 @@ except ImportError:
 yaml = YAML(typ="safe")
 
 
-def from_yaml(
-    path: Optional[Union[str, Path]] = None, enc: Optional[str] = None
-) -> Graph:
+def from_yaml(path: Optional[Union[str, Path]] = None, enc: Optional[str] = None) -> Graph:
     """Decode YAML file or string into a Graph.
 
     Arguments:
