@@ -1,4 +1,4 @@
-"""Re-usable mapping plot component.
+"""# Piechart mapping matrix plot component
 
 The mapping plot is a matrix of pie-charts, indicating the edges between leaf nodes.
 
@@ -20,6 +20,7 @@ from math import cos, pi, prod, sin
 from typing import Any, Dict, List, Tuple
 
 import plotly.graph_objs as go
+
 from ragraph import colors
 from ragraph.edge import Edge
 from ragraph.node import Node
@@ -37,8 +38,6 @@ class PieMap(Component):
         cols: The columns to be placed on the columns of the matrix.
         edges: Edges to be displayed between leaf nodes.
         style: Plot style option mapping.
-        rows: The nodes to be placed on the rows of the matrix.
-        cols: The columns to be placed on the columns of the matrix.
 
     Note:
         The pie-charts can represent a number of things, including edge weights, edge
@@ -78,9 +77,7 @@ class PieMap(Component):
 
         # Combine all traces and shapes.
         traces = pie_traces
-        shapes = (
-            highlight_shapes + grid_shapes + pie_shapes + kind_shapes + hierarchy_shapes
-        )
+        shapes = highlight_shapes + grid_shapes + pie_shapes + kind_shapes + hierarchy_shapes
 
         dim = (len(rows), len(cols))
         xaxis, yaxis = deepcopy(style.piemap.xaxis), deepcopy(style.piemap.yaxis)
@@ -112,14 +109,10 @@ def _get_grid_shapes(rows: List[Node], cols: List[Node], style: Style):
 
     # Gridlines
     shapes = [
-        svg.get_line(
-            x0=0, x1=dim[1] * xstep, y0=i * ystep, y1=i * ystep, line=line
-        ).as_dict()
+        svg.get_line(x0=0, x1=dim[1] * xstep, y0=i * ystep, y1=i * ystep, line=line).as_dict()
         for i in range(dim[0] + 1)
     ] + [
-        svg.get_line(
-            x0=j * xstep, x1=j * xstep, y0=0, y1=dim[0] * ystep, line=line
-        ).as_dict()
+        svg.get_line(x0=j * xstep, x1=j * xstep, y0=0, y1=dim[0] * ystep, line=line).as_dict()
         for j in range(dim[1] + 1)
     ]
 
@@ -140,9 +133,7 @@ def _get_grid_shapes(rows: List[Node], cols: List[Node], style: Style):
     return shapes
 
 
-def _get_highlight_shapes(
-    rows: List[Node], cols: List[Node], style: Style
-) -> List[Dict[str, Any]]:
+def _get_highlight_shapes(rows: List[Node], cols: List[Node], style: Style) -> List[Dict[str, Any]]:
     """Get highlight bands for both rows and columns."""
     row_annot = (
         style.piemap.highlight_row_annotation
@@ -251,9 +242,7 @@ def _get_pies_data(rows: List[Node], cols: List[Node], edges: List[Edge], style:
 
             # Equal angles if calculated else calculate relative ones.
             field_angles = (
-                _get_relative_angles(fields, field_values)
-                if equal_angles is None
-                else equal_angles
+                _get_relative_angles(fields, field_values) if equal_angles is None else equal_angles
             )
 
             # Get the scaled radius.
@@ -363,7 +352,7 @@ def _get_fields(edges: List[Edge], style: Style) -> List[str]:
     if display == "kinds":
         fields = set(e.kind for e in edges)
     elif display == "labels":
-        fields = set(l for e in edges for l in e.labels)
+        fields = set(label for e in edges for label in e.labels)
     elif display in {"weight labels", "weights"}:
         fields = set(wl for e in edges for wl in e.weights.keys())
     else:
@@ -381,9 +370,7 @@ def _check_categorical_color_settings(fields: List[str], style: Style):
         style.palettes.categorical = colors.get_categorical(len(fields))
 
 
-def _get_field_values(
-    edges: List[Edge], fields: List[str], style: Style
-) -> Dict[str, float]:
+def _get_field_values(edges: List[Edge], fields: List[str], style: Style) -> Dict[str, float]:
     """Get the field sums for the given edges according to the style."""
     field_map: Dict[str, float] = dict()
     if not edges:
@@ -409,9 +396,7 @@ def _get_field_values(
             if sum(f in e.weights for e in edges)
         }
     elif display == "weights":
-        field_map = {
-            f: float(sum(e.weights.get(f, 0.0) for e in edges)) for f in fields
-        }
+        field_map = {f: float(sum(e.weights.get(f, 0.0) for e in edges)) for f in fields}
     else:
         field_map = dict(num=float(len(edges)))
     return field_map
@@ -419,11 +404,9 @@ def _get_field_values(
 
 def _get_equal_angles(fields: List[str]) -> Dict[str, Tuple[float, float]]:
     """Get piechart angle dictionary."""
-    delta = 2 * pi / len(fields)
+    delta = 2 * pi / len(fields) if fields else 2 * pi
     offset = pi / 2  # Start upright, then go clockwise for intuitive results.
-    return {
-        f: (offset - (i + 1) * delta, offset - i * delta) for i, f in enumerate(fields)
-    }
+    return {f: (offset - (i + 1) * delta, offset - i * delta) for i, f in enumerate(fields)}
 
 
 def _get_relative_angles(
@@ -530,7 +513,7 @@ def _get_pie_data(
     return traces, shapes
 
 
-def _get_hierarchy_shapes(leafs: List[Node], style: Style):
+def _get_hierarchy_shapes(leafs: List[Node], style: Style) -> List[Dict[str, Any]]:
     """Get hierarchy shapes for the mapping plot component.
 
     Arguments:
@@ -538,17 +521,14 @@ def _get_hierarchy_shapes(leafs: List[Node], style: Style):
       style: Style of the tree to be plotted.
 
     Returns:
-        Processed ancestor nodes.
-        Tree depth.
-        Dictionary of node to x position of tree nodes.
-        Dictionary of node to y position of tree nodes.
+        Hierarchy shapes as SVG mappings converted to dictionaries.
     """
 
-    shapes = []
+    shapes: List[Dict[str, Any]] = []
 
     # Plot geometrics
     x_step, y_step = style.xstep, style.ystep
-    tree_depth = max([node.depth for node in leafs])
+    tree_depth = max([node.depth for node in leafs], default=0)
     dim = len(leafs)
 
     # Compute leaf node positions.
@@ -575,7 +555,7 @@ def _get_hierarchy_shapes(leafs: List[Node], style: Style):
             children = [child for child in parent.children if child in odict]
 
             # Offset is minimum value.
-            offset = min(odict[n] for n in children)
+            offset = min(odict[n] for n in children) if children else 0
             odict[parent] = offset
 
             # Size is sum of child sizes.
@@ -634,14 +614,16 @@ def _get_hierarchy_shapes(leafs: List[Node], style: Style):
     return shapes
 
 
-def _get_kind_shapes(leafs: List[Node], style: Style):
+def _get_kind_shapes(leafs: List[Node], style: Style) -> List[svg.SVG]:
     """Get kind shapes for the mapping plot component."""
+    shapes = []
+    if not leafs:
+        return shapes
     dim = len(leafs)
     line = style.piemap.kindline
 
     # Get the indexes of leafs that "change" the kind and append lines afterwards.
     kind = leafs[0].kind
-    shapes = []
     for i, node in enumerate(leafs):
         if node.kind == kind:
             continue
