@@ -1,9 +1,10 @@
-"""RaGraph generic plotting classes such as :obj:`Component` and :obj:`Style`."""
+"""# RaGraph generic plotting classes"""
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from plotly import graph_objs as go
 from plotly.basedatatypes import BaseTraceType
+
 from ragraph import colors
 from ragraph.generic import Mapping, field
 from ragraph.plot import svg
@@ -96,15 +97,15 @@ class TreeStyle(Mapping):
         super().__init__(line=line, xaxis=xaxis, yaxis=yaxis)
 
     @field
-    def line(self) -> svg.Line:
+    def line(self) -> svg.Line:  # type: ignore
         """Line style mapping for hierarchy tree lines."""
 
     @field
-    def xaxis(self) -> go.layout.XAxis:
+    def xaxis(self) -> go.layout.XAxis:  # type: ignore
         """Plotly X-axis settings."""
 
     @field
-    def yaxis(self) -> go.layout.YAxis:
+    def yaxis(self) -> go.layout.YAxis:  # type: ignore
         """Plotly Y-axis settings."""
 
 
@@ -182,37 +183,37 @@ class LabelsStyle(Mapping):
         )
 
     @field
-    def fontcolor(self) -> str:
+    def fontcolor(self) -> str:  # type: ignore
         """Font color used for labels."""
 
     @field
-    def fontfamily(self) -> str:
+    def fontfamily(self) -> str:  # type: ignore
         """Font family used for labels."""
 
     @field
-    def fontsize(self) -> int:
+    def fontsize(self) -> int:  # type: ignore
         """Fontsize used for labels."""
 
     @field
-    def fontaspectratio(self) -> float:
+    def fontaspectratio(self) -> float:  # type: ignore
         """Font width per fontsize ratio."""
 
     @field
-    def shorten(self) -> Union[bool, Callable[[str], str]]:
+    def shorten(self) -> Union[bool, Callable[[str], str]]:  # type: ignore
         """Label shortening toggle or function. When set to `True` everything after
         the last dot '.' is kept.
         """
 
     @field
-    def textorientation(self) -> float:
+    def textorientation(self) -> float:  # type: ignore
         """Orientation of text."""
 
     @field
-    def xaxis(self) -> go.layout.XAxis:
+    def xaxis(self) -> go.layout.XAxis:  # type: ignore
         """Plotly X-axis settings."""
 
     @field
-    def yaxis(self) -> go.layout.YAxis:
+    def yaxis(self) -> go.layout.YAxis:  # type: ignore
         """Plotly Y-axis settings."""
 
 
@@ -222,14 +223,14 @@ class PieMapStyle(Mapping):
     Arguments:
         busarea: Bus area SVG mapping. Used for styling the bus area.
         display: What to display. One of 'kinds', 'labels', 'weight labels', 'weights'.
-        fields: The fields to plot (the selection of kinds, labels, or weights).
-            Leave set to `None` to display all the available fields automatically.
+        fields: The fields to plot (the selection of kinds, labels, or weights). Leave set to `None`
+            to display all the available fields automatically.
         gridline: Grid line options mapping.
-        highlight_col_annotation: Annotation that signals what columns should be
-            highlighted. Value should be True-ish.
+        highlight_col_annotation: Annotation that signals what columns should be highlighted.
+            Value should be True-ish.
         highlight_col_color: Default color to use for column highlights.
-        highlight_row_annotation: Annotation that signals what rows should be
-            highlighted. Value should be True-ish.
+        highlight_row_annotation: Annotation that signals what rows should be highlighted.
+            Value should be True-ish.
         highlight_row_color: Default color to use for row highlights.
         inherit: Whether to display edges between descendants of the axis nodes.
         kindline: Node kind separation lines options mapping.
@@ -237,24 +238,21 @@ class PieMapStyle(Mapping):
             'equal' divides the piechart evenly.
             'relative' divides the piechart according to category value.
         radius: The piechart radius between 0.0 and 0.5.
-        scale_weight: Edge weight label that should contain values between 0.0 and 1.0
-            to scale the radius with.
+        scale_weight: Edge weight label that should contain values between 0.0 and 1.0 to scale the
+            radius with.
         customhoverkeys: List of keys for information to be displayed on hover.
         xaxis: Plotly X-axis settings.
         yaxis: Plotly Y-axis settings.
 
     Note:
-        The :obj:`display` argument determines what is going to be plotted as piecharts
-        in the plot area. The :obj:`fields` argument is a filter on the possible
-        values for that display mode. The :obj:`mode` argument then tunes how the wedges
-        that make up the piecharts should be distributed. Most of the time, 'equal'
-        gives the most predictable and clear results.
+        The `display` argument determines what is going to be plotted as piecharts in the plot area.
+        The `fields` argument is a filter on the possible values for that display mode. The `mode`
+        argument then tunes how the wedges that make up the piecharts should be distributed. Most of
+        the time, 'equal' gives the most predictable and clear results.
     """
 
     _defaults = dict(
-        busarea=svg.SVG(
-            fillcolor="rgba(150,150,150,0.2)", line=svg.Line(width=0), layer="below"
-        ),
+        busarea=svg.SVG(fillcolor="rgba(150,150,150,0.2)", line=svg.Line(width=0), layer="below"),
         clusterline=svg.Line(width=2, color="gray", dash="solid"),
         display="kinds",
         fields=None,
@@ -341,78 +339,78 @@ class PieMapStyle(Mapping):
         )
 
     @field
-    def busarea(self) -> svg.SVG:
+    def busarea(self) -> svg.SVG:  # type: ignore
         """Bus area SVG mapping. Used for styling the bus area."""
 
     @field
-    def display(self) -> str:
+    def display(self) -> str:  # type: ignore
         """What to display. One of 'kinds', 'labels', 'weight labels', 'weights'."""
 
     @field
-    def fields(self) -> List[str]:
+    def fields(self) -> List[str]:  # type: ignore
         """The fields to plot (the selection of kinds, labels, or weights). Leave set
         to `None` to display all the available fields automatically.
         """
 
     @field
-    def gridline(self) -> svg.Line:
+    def gridline(self) -> svg.Line:  # type: ignore
         """Grid line style."""
 
     @field
-    def highlight_col_annotation(self) -> Optional[str]:
+    def highlight_col_annotation(self) -> Optional[str]:  # type: ignore
         """Annotation that signals what columns should be highlighted.
         Value should be True-ish.
         """
 
     @field
-    def highlight_col_color(self) -> Optional[str]:
+    def highlight_col_color(self) -> Optional[str]:  # type: ignore
         """Default color to use for column highlights."""
 
     @field
-    def highlight_row_annotation(self) -> Optional[str]:
+    def highlight_row_annotation(self) -> Optional[str]:  # type: ignore
         """Annotation that signals what rows should be highlighted.
         Value should be True-ish.
         """
 
     @field
-    def highlight_row_color(self) -> Optional[str]:
+    def highlight_row_color(self) -> Optional[str]:  # type: ignore
         """Default color to use for row highlights."""
 
     @field
-    def inherit(self) -> bool:
+    def inherit(self) -> bool:  # type: ignore
         """Whether to display edges between descendants of the axis nodes."""
 
     @field
-    def kindline(self) -> svg.Line:
+    def kindline(self) -> svg.Line:  # type: ignore
         """Node kind separation lines options mapping."""
 
     @field
-    def mode(self) -> str:
+    def mode(self) -> str:  # type: ignore
         """How to divide the piecharts per field. Either 'equal' or 'relative'.
         'equal' divides the piecharts evenly.
         'relative' divides the piechart according to field value.
         """
 
     @field
-    def radius(self) -> float:
+    def radius(self) -> float:  # type: ignore
         """The piechart radius between 0.0 and 0.5."""
 
     @field
-    def scale_weight(self) -> str:
+    def scale_weight(self) -> str:  # type: ignore
         """Edge weight label that should contain values between 0.0 and 1.0 to scale the
         radius with.
         """
 
     @field
-    def customhoverkeys(self) -> List[str]:
+    def customhoverkeys(self) -> List[str]:  # type: ignore
         """Custom keys for information to be displayed on hover."""
 
     @field
-    def xaxis(self) -> go.layout.XAxis:
+    def xaxis(self) -> go.layout.XAxis:  # type: ignore
         """Plotly X-axis settings."""
 
     @field
-    def yaxis(self) -> go.layout.YAxis:
+    def yaxis(self) -> go.layout.YAxis:  # type: ignore
         """Plotly Y-axis settings."""
 
 
@@ -437,11 +435,11 @@ class FieldPalette(Mapping):
         super().__init__(self, categorical=categorical, continuous=continuous)
 
     @field
-    def categorical(self) -> Optional[str]:
+    def categorical(self) -> Optional[str]:  # type: ignore
         """Categorical color for this field."""
 
     @field
-    def continuous(self) -> Optional[List[str]]:
+    def continuous(self) -> Optional[List[str]]:  # type: ignore
         """Continuous (numeric) data color palette for this field."""
 
 
@@ -452,8 +450,8 @@ class Palettes(Mapping):
         categorical: Categorical data color palette.
         continuous: Continuous (numeric) data color palette.
         fields: Palette override dictionary per display field.
-        domains: Value domains to interpolate palettes between per field as a tuple
-            of (lower, upper) bounds. Only used for continuous fields.
+        domains: Value domains to interpolate palettes between per field as a tuple of
+            (lower, upper) bounds. Only used for continuous fields.
     """
 
     _defaults = dict(
@@ -477,9 +475,7 @@ class Palettes(Mapping):
             domains=domains,
         )
 
-    def get_categorical_palette(
-        self, field: Optional[str] = None
-    ) -> Union[str, List[str]]:
+    def get_categorical_palette(self, field: Optional[str] = None) -> Union[str, List[str]]:
         """Get a categorical color (palette). Might be an overridden color, colorlist,
         or the default palette for the given field."""
         palette = self.fields.get(field, self.categorical)
@@ -546,19 +542,19 @@ class Palettes(Mapping):
         return palette[idx]
 
     @field
-    def categorical(self) -> List[str]:
+    def categorical(self) -> List[str]:  # type: ignore
         """Categorical data color palette."""
 
     @field
-    def continuous(self) -> List[str]:
+    def continuous(self) -> List[str]:  # type: ignore
         """Continuous (numeric) data color palette."""
 
     @field
-    def fields(self) -> Dict[str, Union[str, List[str], FieldPalette]]:
+    def fields(self) -> Dict[str, Union[str, List[str], FieldPalette]]:  # type: ignore
         """Palette override dictionary per display field."""
 
     @field
-    def domains(self) -> Dict[str, Tuple[float, float]]:
+    def domains(self) -> Dict[str, Tuple[float, float]]:  # type: ignore
         """Value domains to interpolate palettes between per field as a tuple of
         (lower, upper), bounds. Only used for continuous fields.
         """
@@ -640,36 +636,36 @@ class LegendStyle(Mapping):
         )
 
     @field
-    def fontcolor(self) -> str:
+    def fontcolor(self) -> str:  # type: ignore
         """Font color used for labels."""
 
     @field
-    def fontfamily(self) -> str:
+    def fontfamily(self) -> str:  # type: ignore
         """Font family used for labels."""
 
     @field
-    def fontsize(self) -> int:
+    def fontsize(self) -> int:  # type: ignore
         """Fontsize used for labels."""
 
     @field
-    def fontaspectratio(self) -> float:
+    def fontaspectratio(self) -> float:  # type: ignore
         """Font width per fontsize ratio."""
 
     @field
-    def height(self) -> int:
+    def height(self) -> int:  # type: ignore
         """Height of the swatch plot in number of box sizes when plotting a
         numerical legend."""
 
     @field
-    def n_ticks(self) -> int:
+    def n_ticks(self) -> int:  # type: ignore
         """Number of ticks in the swatch plot when plotting a numerical legend."""
 
     @field
-    def xaxis(self) -> go.layout.XAxis:
+    def xaxis(self) -> go.layout.XAxis:  # type: ignore
         """Plotly X-axis settings."""
 
     @field
-    def yaxis(self) -> go.layout.YAxis:
+    def yaxis(self) -> go.layout.YAxis:  # type: ignore
         """Plotly Y-axis settings."""
 
 
@@ -760,60 +756,60 @@ class Style(Mapping):
         )
 
     @field
-    def boxsize(self) -> int:
+    def boxsize(self) -> int:  # type: ignore
         """Size in pixels per row or column."""
 
     @field
-    def config(self) -> Dict[str, Any]:
+    def config(self) -> Dict[str, Any]:  # type: ignore
         """Plotly Figure.show() config."""
 
     @field
-    def highlight_annotation(self) -> Optional[str]:
+    def highlight_annotation(self) -> Optional[str]:  # type: ignore
         """Annotation key of instances that should be highlighted.
         Value should be True-ish. Set key to `None` to disable."""
 
     @field
-    def highlight_color(self) -> str:
+    def highlight_color(self) -> str:  # type: ignore
         """Default color to use for highlights."""
 
     @field
-    def labels(self) -> LabelsStyle:
+    def labels(self) -> LabelsStyle:  # type: ignore
         """Labels plot style."""
 
     @field
-    def layout(self) -> go.Layout:
+    def layout(self) -> go.Layout:  # type: ignore
         """Layout options."""
 
     @field
-    def palettes(self) -> Palettes:
+    def palettes(self) -> Palettes:  # type: ignore
         """Plot palettes options."""
 
     @field
-    def piemap(self) -> PieMapStyle:
+    def piemap(self) -> PieMapStyle:  # type: ignore
         """Piechart map plot style."""
 
     @field
-    def tree(self) -> TreeStyle:
+    def tree(self) -> TreeStyle:  # type: ignore
         """Tree plot style."""
 
     @field
-    def legend(self) -> LegendStyle:
+    def legend(self) -> LegendStyle:  # type: ignore
         """Legend plot style."""
 
     @field
-    def show_legend(self) -> bool:
+    def show_legend(self) -> bool:  # type: ignore
         """Boolean to display a legend."""
 
     @field
-    def row_col_numbers(self) -> bool:
+    def row_col_numbers(self) -> bool:  # type: ignore
         """Boolean to display row and column numbers."""
 
     @field
-    def xstep(self) -> float:
+    def xstep(self) -> float:  # type: ignore
         """Axis increment per row or column in plots (usually 1)."""
 
     @field
-    def ystep(self) -> float:
+    def ystep(self) -> float:  # type: ignore
         """Axis increment per row or column in plots (usually 1)."""
 
 
@@ -872,36 +868,34 @@ class Component(Mapping):
         )
 
     @field
-    def width(self) -> float:
+    def width(self) -> float:  # type: ignore
         """Width in pixels."""
 
     @field
-    def height(self) -> float:
+    def height(self) -> float:  # type: ignore
         """Height in pixels."""
 
     @field
-    def traces(self) -> List[BaseTraceType]:
+    def traces(self) -> List[BaseTraceType]:  # type: ignore
         """Traces to plot in this domain."""
 
     @field
-    def shapes(self) -> List[Dict[str, Any]]:
+    def shapes(self) -> List[Dict[str, Any]]:  # type: ignore
         """SVG shapes from this component."""
 
     @field
-    def annotations(self) -> List[Dict[str, Any]]:
+    def annotations(self) -> List[Dict[str, Any]]:  # type: ignore
         """Annotations from this component."""
 
     @field
-    def xaxis(self) -> go.layout.XAxis:
+    def xaxis(self) -> go.layout.XAxis:  # type: ignore
         """Plotly X-axis options."""
 
     @field
-    def yaxis(self) -> go.layout.YAxis:
+    def yaxis(self) -> go.layout.YAxis:  # type: ignore
         """Plotly Y-axis options."""
 
-    def get_figure(
-        self, style: Style = Style(), show: bool = True
-    ) -> Optional[go.Figure]:
+    def get_figure(self, style: Style = Style(), show: bool = True) -> Optional[go.Figure]:
         """Get a Plotly figure of this component alone."""
         from ragraph.plot.utils import get_subplots, process_fig
 
